@@ -24,7 +24,7 @@
   @author Copyright (C) 2004 Philippe April <papril777@yahoo.com>
   @author Copyright (C) 2004 Alexandre Carmel-Veilleux <acv@miniguru.ca>
   @author Copyright (C) 2008 Paul Kube <nodogsplash@kokoro.ucsd.edu>
-  @author Copyright (C) 2015-2024 Modifications and additions by BlueWave Projects and Services <opennds@blue-wave.net>
+  @author Copyright (C) 2015-2025 Modifications and additions by BlueWave Projects and Services <opennds@blue-wave.net>
  */
 
 
@@ -348,21 +348,25 @@ setup_from_config(void)
 	int major = 0;
 	int minor = 0;
 	int patch = 0;
-	int outdated = 0;
+	int outdated = 1;
 	const char *version = MHD_get_version();
 
 	debug(LOG_NOTICE, "MHD version is %s", version);
 
 	if (sscanf(version, "%d.%d.%d", &major, &minor, &patch) == 3) {
 
-		if (major < MIN_MHD_MAJOR) {
-			outdated = 1;
+		if (major >= MIN_MHD_MAJOR) {
+			outdated = 0;
 
-		} else if (minor < MIN_MHD_MINOR) {
-			outdated = 1;
+		}
 
-		} else if (patch < MIN_MHD_PATCH) {
-			outdated = 1;
+		if (outdated == 0 && minor >= MIN_MHD_MINOR) {
+			outdated = 0;
+
+		}
+
+		if (outdated == 0 && patch >= MIN_MHD_PATCH) {
+			outdated = 0;
 		}
 
 		if (outdated == 1) {
